@@ -14,12 +14,9 @@ use Sys::Hostname;
 use Sys::Syslog;
 use Errorlog::TeeOutput;
 
-#
-# Can't locate object method "BINMODE" via package "Errorlog::TeeOutput::NewTee" at /home/anton/bin/keymaster line 10.
-#
+my $version = '$Id: Errorlog.pm 40915 2014-01-30 11:53:50Z anton $ ';
+our $VERSION = "1.35";
 
-my $version = '$Id: Errorlog.pm 40359M 2013-10-04 11:32:20Z (local) $ ';
-our $VERSION = "1.34";
 #global variable, needed for TeeOutput
 our $SELF;
 
@@ -41,7 +38,8 @@ sub import {
 sub end {
 	carp  "Errorlog:end; Exitcode is: $?"  if $Baseobject::verbosity >=2;
 	if ($SELF->{fields}->{mailonfailure}){
-		my $logbuffer = $SELF->{fields}->{logbuffer} if $SELF->{fields}->{logbuffer};
+		my $logbuffer = 'no logbuffer'; 
+		$logbuffer = $SELF->{fields}->{logbuffer} if $SELF->{fields}->{logbuffer};
 		$SELF->mail("Errorlog v$VERSION failure: Errorstatus: $?, \n$logbuffer") ;
 	}
 }
@@ -57,7 +55,6 @@ END {
 	$? = $status;
 }
 
-
 sub new {
 	my $pkg = shift;
 	my $self = bless (new Baseobject(@_),$pkg);
@@ -95,7 +92,7 @@ sub new {
 			'newrunmarker' => '-'x60,
 			'output' => [qw (stderr logbuffer)],
 			'printinfo' => 1,
-			'sysloglevel' => 'info',
+			'sysloglevel' => 'debug',
 			'syslogmaxbuf' => 512 + 255, # just guessing, 1024 is too big, things get truncated
 			'hirestimer' => 0,
 			'user' => $user,
@@ -127,13 +124,6 @@ sub new {
 	my %params;
 	my $syslogSuppressed = '';
 
-	if ($self->{outputmodes}->{syslog}) {
-		if (openlog($0, 'cons,pid',$self->{fields}->{facility}) ) {
-			$params{'syslog'} = 1; #1 is dummy value
-		} else {
-			$self->error("Could not open syslog");
-		}
-	}
 
 	if ($self->{fields}->{noDebug2Syslog}) {
 		if ($Baseobject::verbosity >= 2) {
@@ -141,13 +131,21 @@ sub new {
 				$syslogSuppressed = "Warning ($0): Debug output is not allowed in syslog but redirected to: \"$logdir/$logfile\"\n";
 				warn $syslogSuppressed;
 				$self->{outputmodes}->{logfile} = 1;
-				syslog('alert', $syslogSuppressed);
+				syslog('debug', $syslogSuppressed);
 				$self->{outputmodes}->{syslog} = 0;
-				closelog();
+#				closelog();
 			}
 		}
 	}
 
+	if ($self->{outputmodes}->{syslog}) {
+		if (openlog($0, 'cons,pid', $self->{fields}->{facility}) ) {
+			$params{'syslog'} = 1; #1 is dummy value
+		} else {
+			$self->error("Could not open syslog");
+		}
+	}
+
 	if ($self->{outputmodes}->{logfile}) {
 		$logdir = $self->field('logdir');
 		$logfile = $self->field('logfile');
